Module: Mince::Model::DataModel::ClassMethods
- Defined in:
- lib/mince/model/data_model.rb
Instance Method Summary collapse
-
#data_model(model = nil) ⇒ Object
Sets or returns the data model class for the model.
Instance Method Details
#data_model(model = nil) ⇒ Object
Sets or returns the data model class for the model
10 11 12 13 |
# File 'lib/mince/model/data_model.rb', line 10 def data_model(model=nil) @data_model = model if model @data_model end |